pub fn read_marker<B: Buf>(r: &mut B) -> Result<Marker>Expand description
Read a marker from the [Buf], this function should only be used for
custom serialisation based on the marker otherwise just use read_epee_value.
pub fn read_marker<B: Buf>(r: &mut B) -> Result<Marker>Read a marker from the [Buf], this function should only be used for
custom serialisation based on the marker otherwise just use read_epee_value.