EpeeValueLimits

Struct EpeeValueLimits 

pub struct EpeeValueLimits {
    pub min_element_size: usize,
    pub max_sequence_len: usize,
}
Limits applied while decoding an epee value.

Fields

min_element_size: usize

This is a safety value that is used to enforce that a minimum number of bytes are read for a given element. This is to protect types where their epee wire encoding could be a lot smaller than their size in memory. This is allowed to be ignored if it is safe for that type to do so.

max_sequence_len: usize

The maximum number of elements allowed in a sequence. Will be ignored when the type is not a sequence.