pub fn read_epee_value<T: EpeeValue, B: Buf>(
r: &mut B,
limits: EpeeValueLimits,
) -> Result<T>Expand description
Read an epee value from the stream, an epee value is the part after the key including the marker.
pub fn read_epee_value<T: EpeeValue, B: Buf>(
r: &mut B,
limits: EpeeValueLimits,
) -> Result<T>Read an epee value from the stream, an epee value is the part after the key including the marker.